@@ -118,12 +118,12 @@ class MomoPayProcessor:
                 self.status_type = StatusTypes.FAILED
 
             try:
-                momo_trans = MomoTransaction.objects.get(
+                self.momotrans = MomoTransaction.objects.get(
                     order_id=self.callback["Order_id"],
                     ext_id=self.callback["InvoiceNo"])
-                momo_trans.final_callback = json.dumps(self.callback , cls=DjangoJSONEncoder)
-                momo_trans.status = self.status_type                
-                momo_trans.save()
-                return {"status":True, "transactionID":momo_trans.id, "amount":momo_trans.amount}
+                self.momotrans.final_callback = json.dumps(self.callback , cls=DjangoJSONEncoder)
+                self.momotrans.status = self.status_type                
+                self.momotrans.save()
+                return {"status":True, "transactionID":self.momotrans.id, "amount":self.momotrans.amount}
             except Exception as e:
                 return {"status":False, "message":f"{e}"}
\ No newline at end of file
